<?php
/*****************************************************************************
 * Copyright (C) 2014-2022
 *   
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of ThermFerm
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * ThermFerm is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/

require_once('utilities.php');
/*
 * Look for the style names in the jqwidgets/styles directory.
 */
$my_style = 'ui-redmond';

$answer = send_cmd('GLOBAL GET');
$arr = explode("\r\n", $answer);
$version = "?";
$simula = false;

if (startsWith($arr[0], "213")) {
    $j = 1;
    while (1) {
	if (strcmp($arr[$j], ".") == 0)
	    break;
	$f = explode(",", $arr[$j]);

	if ($f[0] == "RELEASE")
	    $version = $f[1];
	$j++;
    }
}

/*
 * See if the server supports simulators
 */
if (send_cmd_check("SIMULATOR LIST") == 0)
    $simula = true;

$outstr  = '<!DOCTYPE html>'.PHP_EOL;
$outstr .= '<html>'.PHP_EOL;
$outstr .= ' <head>'.PHP_EOL;
$outstr .= '  <meta http-equiv="content-type" content="text/html; charset=utf-8" />'.PHP_EOL;
$outstr .= '  <title>ThermFerm - Maintenance Menu</title>'.PHP_EOL;
$outstr .= '  <link type="text/css" href="css/style.css" rel="stylesheet" media="all" />'.PHP_EOL;
$outstr .= '  <link type="text/css" href="jqwidgets/styles/jqx.base.css" rel="stylesheet" />'.PHP_EOL;
$outstr .= '  <link type="text/css" href="jqwidgets/styles/jqx.'.$my_style.'.css" rel="stylesheet" />'.PHP_EOL;
$outstr .= '  <script type="text/javascript" src="js/jquery-2.1.1.min.js"></script>'.PHP_EOL;
$outstr .= '  <script type="text/javascript" src="jqwidgets/jqxcore.js"></script>'.PHP_EOL;
$outstr .= '  <script type="text/javascript" src="jqwidgets/jqxwindow.js"></script>'.PHP_EOL;
$outstr .= '  <script type="text/javascript" src="jqwidgets/jqxbuttons.js"></script>'.PHP_EOL;
$outstr .= ' </head>'.PHP_EOL;
$outstr .= ' <body class="default">'.PHP_EOL;
$outstr .= '  <div id="jqxWidget">'.PHP_EOL;
$outstr .= '   <div id="header">'.PHP_EOL;
$outstr .= '    <div id="title">'.PHP_EOL;
$outstr .= '     ThermFerm '.$version.PHP_EOL;
$outstr .= '    </div>'.PHP_EOL;
$outstr .= '    <form action="index.php" style="margin:30px; float:right">'.PHP_EOL;
$outstr .= '     <input type="submit" id="maintenance" value="Dashboard" />'.PHP_EOL;
$outstr .= '    </form>'.PHP_EOL;
$outstr .= '   </div> <!-- header -->'.PHP_EOL;
$outstr .= '   <div id="content">'.PHP_EOL;
$outstr .= '    <div id="menu">'.PHP_EOL;
$outstr .= '     <div id="menu_header">'.PHP_EOL;
$outstr .= '      Maintenance Menu'.PHP_EOL;
$outstr .= '     </div>'.PHP_EOL;
$outstr .= '     <div id="menu_left">'.PHP_EOL;
$outstr .= '      <form action="global.php" style="margin:20px;">'.PHP_EOL;
$outstr .= '       <input type="submit" id="global" value="Global Setup" />'.PHP_EOL;
$outstr .= '      </form>'.PHP_EOL;
$outstr .= '      <form action="devices.php" style="margin:20px;">'.PHP_EOL;
$outstr .= '       <input type="submit" id="devices" value="Devices Setup" />'.PHP_EOL;
$outstr .= '      </form>'.PHP_EOL;
$outstr .= '     </div>'.PHP_EOL;
$outstr .= '     <div id="menu_right">'.PHP_EOL;
$outstr .= '      <form action="units.php" style="margin:20px;">'.PHP_EOL;
$outstr .= '       <input type="submit" id="units" value="Fermentation Units" />'.PHP_EOL;
$outstr .= '      </form>'.PHP_EOL;
if ($simula) {
    $outstr .= '      <form action="simulator.php" style="margin:20px;">'.PHP_EOL;
    $outstr .= '       <input type="submit" id="simulator" value="Simulator Setup" />'.PHP_EOL;
    $outstr .= '      </form>'.PHP_EOL;
}
$outstr .= '     </div>'.PHP_EOL;
$outstr .= '    </div>'.PHP_EOL;
$outstr .= '    <script type="text/javascript">'.PHP_EOL;
$outstr .= '     $(document).ready(function () {'.PHP_EOL;
$outstr .= '      $("#maintenance").jqxButton({ width: 150, height: 25, theme: \'ui-redmond\' });'.PHP_EOL;
$outstr .= '      $("#global").jqxButton({ width: 200, height: 25, theme: \'ui-redmond\' });'.PHP_EOL;
$outstr .= '      $("#devices").jqxButton({ width: 200, height: 25, theme: \'ui-redmond\' });'.PHP_EOL;
$outstr .= '      $("#units").jqxButton({ width: 200, height: 25, theme: \'ui-redmond\' });'.PHP_EOL;
if ($simula)
    $outstr .= '      $("#simulator").jqxButton({ width: 200, height: 25, theme: \'ui-redmond\' });'.PHP_EOL;
$outstr .= '     });'.PHP_EOL;
$outstr .= '    </script>'.PHP_EOL;
$outstr .= build_footer();

echo $outstr;

